# PriceIncreaseOption

Applies an automatic price change when a termed subscription is renewed. 

## Enum

* `FROMTENANTPERCENTAGEVALUE` (value: `'FromTenantPercentageValue'`)

* `SPECIFICPERCENTAGEVALUE` (value: `'SpecificPercentageValue'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


